pub struct LaneThresholds { /* private fields */ }Expand description
Transport cutovers for the planner lanes.
Implementations
Sourceimpl LaneThresholds
impl LaneThresholds
Sourcepub const fn rest_max_batch_size(&self) -> usize
pub const fn rest_max_batch_size(&self) -> usize
Returns the maximum batch size before the planner should avoid REST.
Sourcepub const fn bulk_min_batch_size(&self) -> usize
pub const fn bulk_min_batch_size(&self) -> usize
Returns the minimum batch size that should prefer bulk transport.