pub fn project_sync_link(
existing: Option<&SyncLink>,
envelope: &ChangeEnvelope,
salesforce_id: Option<&SalesforceId>,
tombstone: bool,
) -> SyncLinkExpand description
Projects the latest sync link row after a successful apply.
pub fn project_sync_link(
existing: Option<&SyncLink>,
envelope: &ChangeEnvelope,
salesforce_id: Option<&SalesforceId>,
tombstone: bool,
) -> SyncLinkProjects the latest sync link row after a successful apply.