Module plan

Module plan 

Pure planner and merge logic for sync envelopes. Pure planner and merge logic for sync envelopes.

Structs

PlanDecision
The final planner decision after merge and lane selection.
PlannerContext
The pure inputs required to plan a change.

Enums

ApplyLane
Apply lanes chosen by the planner.
MergeOutcome
The result of merging payloads before lane selection.

Functions

merge_payload
Merges an incoming payload into the current payload using field ownership rules.
plan_change
Plans how a change should be applied after merge resolution.