pub struct PlannerContext {
pub object: ObjectSync,
pub current_payload: Option<Value>,
pub batch_size: usize,
pub urgent: bool,
pub has_dependencies: bool,
}Expand description
The pure inputs required to plan a change.
Fields
object: ObjectSyncObject-level sync configuration.
current_payload: Option<Value>The current canonical payload, if one is already known.
batch_size: usizeThe number of records being planned together.
urgent: boolWhether the record should favor the fast path over batch economics.
has_dependencies: boolWhether the change depends on related records being applied together.