pub struct SalesforceApplier<A: Authenticator> { /* private fields */ }Expand description
Minimal Salesforce REST applier for force-sync lanes.
Implementations
Sourceimpl<A: Authenticator> SalesforceApplier<A>
impl<A: Authenticator> SalesforceApplier<A>
Sourcepub const fn new(client: ForceClient<A>) -> Self
pub const fn new(client: ForceClient<A>) -> Self
Creates a new applier from an authenticated force client.
Sourcepub async fn apply_rest_upsert(
&self,
sobject: &str,
external_id_field: &str,
external_id_value: &str,
payload: &Value,
) -> Result<RestApplyResult, ApplyError>
pub async fn apply_rest_upsert( &self, sobject: &str, external_id_field: &str, external_id_value: &str, payload: &Value, ) -> Result<RestApplyResult, ApplyError>
Applies an external-ID upsert using the idempotent REST lane.
Errors
Returns a retryable or permanent apply error if the request fails.
Sourcepub async fn apply_rest_delete(
&self,
sobject: &str,
salesforce_id: &SalesforceId,
) -> Result<(), ApplyError>
pub async fn apply_rest_delete( &self, sobject: &str, salesforce_id: &SalesforceId, ) -> Result<(), ApplyError>
Applies a REST delete using a known Salesforce record ID.
Errors
Returns a retryable or permanent apply error if the request fails.
Sourcepub async fn apply_bulk_upsert<T>(
&self,
sobject: &str,
external_id_field: &str,
batch_size: usize,
records: Vec<T>,
) -> Result<SmartIngestResult, ApplyError>
pub async fn apply_bulk_upsert<T>( &self, sobject: &str, external_id_field: &str, batch_size: usize, records: Vec<T>, ) -> Result<SmartIngestResult, ApplyError>
Applies a bulk upsert using an external ID field and configured batch size.
Errors
Returns a retryable or permanent apply error if the bulk job fails.