pub struct SyncEngineBuilder<A: Authenticator> { /* private fields */ }Expand description
Builder for SyncEngine.
Implementations
Sourceimpl<A: Authenticator> SyncEngineBuilder<A>
impl<A: Authenticator> SyncEngineBuilder<A>
Sourcepub fn object(self, object: ObjectSync) -> Self
pub fn object(self, object: ObjectSync) -> Self
Adds an object sync definition.
Sourcepub const fn reconcile_batch_size(self, reconcile_batch_size: i64) -> Self
pub const fn reconcile_batch_size(self, reconcile_batch_size: i64) -> Self
Sets the number of records scanned per reconciliation pass.
Sourcepub const fn apply_batch_size(self, apply_batch_size: i64) -> Self
pub const fn apply_batch_size(self, apply_batch_size: i64) -> Self
Sets the number of tasks leased for each apply pass.
Sourcepub fn build(self) -> Result<SyncEngine<A>, ForceSyncError>
pub fn build(self) -> Result<SyncEngine<A>, ForceSyncError>