pub struct ChangeEnvelope { /* private fields */ }Expand description
Canonical sync event stored in the journal and passed to planners.
Implementations
Sourceimpl ChangeEnvelope
impl ChangeEnvelope
Sourcepub const fn new(
sync_key: SyncKey,
source: SourceSystem,
operation: ChangeOperation,
observed_at: DateTime<Utc>,
payload: Value,
) -> Self
pub const fn new( sync_key: SyncKey, source: SourceSystem, operation: ChangeOperation, observed_at: DateTime<Utc>, payload: Value, ) -> Self
Creates a new change envelope with no replay cursor.
Sourcepub fn with_cursor(self, cursor: SourceCursor) -> Self
pub fn with_cursor(self, cursor: SourceCursor) -> Self
Attaches a replay cursor to the envelope.
Sourcepub const fn source(&self) -> SourceSystem
pub const fn source(&self) -> SourceSystem
Returns the source system for the change.
Sourcepub const fn operation(&self) -> ChangeOperation
pub const fn operation(&self) -> ChangeOperation
Returns the operation carried by the change.
Sourcepub const fn cursor(&self) -> Option<&SourceCursor>
pub const fn cursor(&self) -> Option<&SourceCursor>
Returns the source cursor, if available.
Sourcepub const fn observed_at(&self) -> DateTime<Utc>
pub const fn observed_at(&self) -> DateTime<Utc>
Returns when the change was observed by the sync engine.
Sourcepub fn payload_hash(&self) -> [u8; 32]
pub fn payload_hash(&self) -> [u8; 32]
Returns a stable hash for the payload contents.
Sourcepub fn payload_hash_matches(&self, other: &Value) -> bool
pub fn payload_hash_matches(&self, other: &Value) -> bool
Returns true when the provided payload hashes to the same value.